# REL12-BP02: Perform post-incident analysis

## Description

Conduct blameless postmortems sau incidents.

## Implementation Guidance

- Hold postmortems within 48 hours
- Focus on process not people
- Identify root causes
- Define action items with owners
- Share learnings broadly

## Risk Level

Medium - Without analysis, incidents repeat.

## Related Best Practices

- [REL12-BP01](REL12-BP01-Use-Playbooks.md)
- [OPS11-BP06](../../01-OPS/OPS11-Evolve-Operations-Evolution/OPS11-BP06-Document-Lessons-Learned.md)
